pub struct RegexBuilder {
pub lookahead_context_max: u32,
/* private fields */
}Fields
lookahead_context_max: u32maximum lookahead context distance before returning AnchorLimit.
Implementations
Sourceimpl RegexBuilder
impl RegexBuilder
pub fn new() -> RegexBuilder
pub fn solver_ref(&self) -> &Solver
pub fn solver(&mut self) -> &mut Solver
pub fn get_tregex(&self, inst: TRegexId) -> &TRegex<TSetId>
pub fn get_nulls( &mut self, pending_rel: u32, mask: Nullability, acc: &mut BTreeSet<NullState>, node_id: NodeId, )
pub fn der( &mut self, node_id: NodeId, mask: Nullability, ) -> Result<TRegexId, AlgebraError>
pub fn num_nodes(&self) -> u32
pub fn get_kind(&self, node_id: NodeId) -> Kind
pub fn strip_lb(&mut self, node_id: NodeId) -> Result<NodeId, AlgebraError>
pub fn reverse(&mut self, node_id: NodeId) -> Result<NodeId, AlgebraError>
pub fn mk_compl(&mut self, body: NodeId) -> NodeId
pub fn mk_concat(&mut self, head: NodeId, tail: NodeId) -> NodeId
pub fn mk_lookbehind(&mut self, lb_body: NodeId, lb_prev: NodeId) -> NodeId
pub fn mk_lookahead( &mut self, la_body: NodeId, la_tail: NodeId, rel: u32, ) -> NodeId
pub fn mk_neg_lookahead(&mut self, body: NodeId, rel: u32) -> NodeId
pub fn mk_neg_lookbehind(&mut self, body: NodeId) -> NodeId
pub fn mk_union(&mut self, left: NodeId, right: NodeId) -> NodeId
pub fn mk_plus(&mut self, body_id: NodeId) -> NodeId
pub fn mk_repeat(&mut self, body_id: NodeId, lower: u32, upper: u32) -> NodeId
pub fn mk_opt(&mut self, body_id: NodeId) -> NodeId
pub fn mk_star(&mut self, body_id: NodeId) -> NodeId
Sourcepub fn nullability_emptystring(&self, node_id: NodeId) -> Nullability
pub fn nullability_emptystring(&self, node_id: NodeId) -> Nullability
it’s cheaper to check this once as an edge-case than to compute a 4th nullability bit for every node
pub fn nullability(&self, node_id: NodeId) -> Nullability
pub fn mk_u8(&mut self, char: u8) -> NodeId
pub fn mk_range_u8(&mut self, start: u8, end_inclusive: u8) -> NodeId
Sourcepub fn extract_literal_prefix(&self, node: NodeId) -> Vec<u8> ⓘ
pub fn extract_literal_prefix(&self, node: NodeId) -> Vec<u8> ⓘ
extract the leading literal byte sequence from a node tree. walks concat chains of single-byte predicates.
pub fn mk_string(&mut self, raw_str: &str) -> NodeId
pub fn mk_unions( &mut self, nodes: impl DoubleEndedIterator<Item = NodeId>, ) -> NodeId
pub fn mk_inters( &mut self, nodes: impl DoubleEndedIterator<Item = NodeId>, ) -> NodeId
pub fn mk_concats( &mut self, nodes: impl DoubleEndedIterator<Item = NodeId>, ) -> NodeId